==> dojo-1.9.4.tgz: package/cldr/nls/sv/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-weekday": "veckodag",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormat-long": "d MMMM y G",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dayPeriods-format-wide-pm": "em",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-yyyyMEd": "E, y-MM-dd G",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "FM",
	"field-era": "era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Mars",
		"April",
		"Maj",
		"Juni",
		"Juli",
		"Augusti",
		"September",
		"Oktober",
		"November",
		"December"
	],
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"field-year": "år",
	"field-hour": "timme",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "i övermorgon",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Maj",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dec"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"BE"
	],
	"field-minute": "minut",
	"field-dayperiod": "fm/em",
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"field-day-relative+-1": "i går",
	"dayPeriods-format-narrow-am": "f",
	"field-day-relative+-2": "i förrgår",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"field-day": "dag",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-zone": "tidszon",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "i fjol",
	"field-month-relative+-1": "förra månaden",
	"dayPeriods-format-abbr-pm": "EM",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "G y-MM-dd",
	"field-month": "månad",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dayPeriods-format-wide-am": "fm",
	"dateFormat-short": "G y-MM-dd",
	"field-second": "sekund",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"dateFormatItem-Ed": "E d",
	"field-week": "vecka",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "förra veckan",
	"dateFormatItem-yyyyM": "G y-MM",
	"field-year-relative+1": "nästa år",
	"dayPeriods-format-narrow-pm": "e",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/sv/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "nu",
	"field-weekday": "Veckodag",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-tue-relative+-1": "tisdag förra veckan",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-wed-relative+-1": "onsdag förra veckan",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dayPeriods-format-wide-pm": "em",
	"dateFormat-full": "EEEE d MMMM y G",
	"dateFormatItem-yyyyMEd": "E, y-MM-dd G",
	"field-thu-relative+-1": "torsdag förra veckan",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "FM",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Mars",
		"April",
		"Maj",
		"Juni",
		"Juli",
		"Augusti",
		"September",
		"Oktober",
		"November",
		"December"
	],
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"field-year": "År",
	"field-hour": "Timme",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"field-day-relative+0": "i dag",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-day-relative+1": "i morgon",
	"field-thu-relative+1": "torsdag nästa vecka",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "i övermorgon",
	"months-standAlone-abbr": [
		"Jan.",
		"Feb.",
		"Mars",
		"Apr.",
		"Maj",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dec."
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"BE"
	],
	"field-minute": "Minut",
	"field-dayperiod": "fm/em",
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"field-day-relative+-1": "i går",
	"dayPeriods-format-narrow-am": "f",
	"field-day-relative+-2": "i förrgår",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-day": "Dag",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-zone": "Tidszon",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "i fjol",
	"field-month-relative+-1": "förra månaden",
	"dayPeriods-format-abbr-pm": "EM",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "G y-MM-dd",
	"field-month": "Månad",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-relative+0": "tisdag denna vecka",
	"field-tue-relative+1": "tisdag nästa vecka",
	"dayPeriods-format-wide-am": "fm",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"dateFormat-short": "G y-MM-dd",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"dateFormatItem-Ed": "E d",
	"field-week": "Vecka",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "förra veckan",
	"dateFormatItem-yyyyM": "G y-MM",
	"field-year-relative+1": "nästa år",
	"dayPeriods-format-narrow-pm": "e",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "måndag förra veckan",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka"
}
//end v1.x content
);
